#!/bin/bash
###############################################################################
# SSS-1276 hotpatch apache cipher
###############################################################################
## (named runbefore to enable reboot)

MOTD=/etc/motd
HOTPATCH_CONFIG=/etc/hotpatch.conf
SW_VERSION=$(grep -o "5[.].[.]." "${MOTD}")

SYSTEM_MODEL_PATH=/srv/www2/app/Model/System.php

host_name="$(/bin/hostname)"
log_format="$(/bin/date +"%b %d %T") ${host_name} ${host_name}: [hotpatch]"
UPDATE_LOG=/home/spectracom/log/update.log
applied=1  # Use a return code, so 0 mean 'true'

FILES_TO_UPDATE=(
    /etc/apache2/sites-enabled/000-httpd-default.conf
    /home/spectracom/default/etc/apache2/sites-enabled/000-httpd-default.conf
)

trap '/bin/sync' EXIT

if ! grep "Version 5[.]9[.][3-5]" "${MOTD}" &>/dev/null; then
    echo "${log_format} version not supported or not found" >> ${UPDATE_LOG}
    exit 1 # A 5.9.x version with the issue was not found
fi


for i in "${FILES_TO_UPDATE[@]}"; do
    sum=$(md5sum "${i}" | cut -d' ' -f1)
    sed -i 's/SSLCipherSuite ECDHE-ECDSA-AES256-GCM-SHA384:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-CHACHA20-POLY1305:ECDHE-RSA-CHACHA20-POLY1305:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES256-SHA384:ECDHE-RSA-AES256-SHA384:ECDHE-ECDSA-AES128-SHA256:ECDHE-RSA-AES128-SHA256/SSLCipherSuite ECDHE-ECDSA-AES256-GCM-SHA384:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-CHACHA20-POLY1305:ECDHE-RSA-CHACHA20-POLY1305:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES128-GCM-SHA256/' "${i}"
    [ "$applied" -ne 0 ] && applied=$([ "$(md5sum "${i}" | cut -d' ' -f1)" != "$sum" ]; echo $?)
done

if [ "${applied}" -ne 0 ]; then
    echo "${log_format} nothing to do, hotpatch not applied" >> ${UPDATE_LOG}
    exit 0
fi

# Generate hotpatch config file
echo "${SW_VERSION} Apache Hisec Disable CBC Ciphers" >> ${HOTPATCH_CONFIG}

# Update patch of /etc/hotpatch.conf
# shellcheck disable=SC1117
sed -i "s/const HOTPATCH_CONFIG = '\/home\/spectracom\/config\/hotpatch.conf';/const HOTPATCH_CONFIG = '\/etc\/hotpatch.conf';/" ${SYSTEM_MODEL_PATH}
